DependencyAnalyzer

Struct DependencyAnalyzer 

pub struct DependencyAnalyzer { /* private fields */ }
Dependency analyzer for automatic workflow construction.

Implementations

Source

impl DependencyAnalyzer

pub fn new(graph: GraphModule) -> Self

Creates a new dependency analyzer with default configuration.

pub fn with_config(graph: GraphModule, config: AutoDetectConfig) -> Self

Creates a new dependency analyzer with custom configuration.

pub async fn detect_dependencies( &self, workflow: &Workflow, ) -> Result<Vec<DependencySuggestion>, WorkflowError>

Detects dependencies between tasks in a workflow.

This method analyzes the workflow’s GraphQueryTasks and suggests dependencies based on symbol impact analysis and reference checking.

Arguments
  • workflow - The workflow to analyze
Returns

A vector of suggested dependencies

pub async fn autocomplete_workflow( &self, partial_workflow: &Workflow, ) -> Result<Workflow, WorkflowError>

Auto-completes a workflow by applying high-confidence dependencies.

Arguments
  • partial_workflow - Workflow to analyze and complete
Returns
  • Ok(Workflow) - Completed workflow with auto-added dependencies
  • Err(WorkflowError) - If validation fails
pub async fn suggest_next_tasks( &self, _workflow: &Workflow, context: &str, ) -> Vec<TaskSuggestion>

Suggests next tasks based on context and graph analysis.

Arguments
  • workflow - Current workflow
  • context - Search context for finding related symbols
Returns

Vector of task suggestions