pub struct ParallelTasks { /* private fields */ }Expand description
Task that executes multiple tasks in parallel using JoinSet.
Tasks are spawned concurrently and all must succeed for the parallel task to succeed. Uses fail-fast behavior on first error.
Implementations
Sourceimpl ParallelTasks
impl ParallelTasks
Sourcepub fn new(tasks: Vec<Box<dyn WorkflowTask>>) -> Self
pub fn new(tasks: Vec<Box<dyn WorkflowTask>>) -> Self
Creates a new parallel tasks wrapper.
Arguments
tasks- Vector of tasks to execute
Example
ⓘ
let task1 = Box::new(FunctionTask::new(
TaskId::new("task1"),
"Task 1".to_string(),
|_ctx| async { Ok(TaskResult::Success) }
));
let task2 = Box::new(FunctionTask::new(
TaskId::new("task2"),
"Task 2".to_string(),
|_ctx| async { Ok(TaskResult::Success) }
));
let parallel = ParallelTasks::new(vec![task1, task2]);Trait Implementations
Sourceimpl WorkflowTask for ParallelTasks
impl WorkflowTask for ParallelTasks
Sourcefn execute<'life0, 'life1, 'async_trait>(
&'life0 self,
context: &'life1 TaskContext,
) -> Pin<Box<dyn Future<Output = Result<TaskResult, TaskError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn execute<'life0, 'life1, 'async_trait>(
&'life0 self,
context: &'life1 TaskContext,
) -> Pin<Box<dyn Future<Output = Result<TaskResult, TaskError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Executes the task with the provided context. Read more
Sourcefn compensation(&self) -> Option<CompensationAction>
fn compensation(&self) -> Option<CompensationAction>
Returns the compensation action for this task (if any). Read more