pub enum RollbackStrategy {
AllDependent,
FailedOnly,
Custom,
}Expand description
Rollback strategy for determining which tasks to roll back.
Variants
AllDependent
Roll back all tasks reachable from failed task (all dependents)
FailedOnly
Roll back only the failed task
Custom
Use custom filter function