pub struct CompensationAction {
pub action_type: CompensationType,
pub description: String,
}Expand description
Compensation action that undoes task side effects.
Describes how to compensate a task during workflow rollback using the Saga pattern. This is a simplified version for use in TaskResult. The full implementation with undo functions is in the rollback module.
Fields
action_type: CompensationTypeType of compensation action
description: StringHuman-readable description of the compensation
Implementations
Sourceimpl CompensationAction
impl CompensationAction
Sourcepub fn new(
action_type: CompensationType,
description: impl Into<String>,
) -> Self
pub fn new( action_type: CompensationType, description: impl Into<String>, ) -> Self
Creates a new CompensationAction.
Sourcepub fn skip(description: impl Into<String>) -> Self
pub fn skip(description: impl Into<String>) -> Self
Creates a Skip compensation (no undo needed).