pub struct GraphQueryTask { /* private fields */ }Expand description
Task that executes graph queries using the Forge SDK.
Queries the code graph for symbols, references, or impact analysis.
Implementations
Sourceimpl GraphQueryTask
impl GraphQueryTask
Sourcepub fn find_symbol(target: impl Into<String>) -> Self
pub fn find_symbol(target: impl Into<String>) -> Self
Creates a new GraphQueryTask for finding a symbol.
Sourcepub fn references(target: impl Into<String>) -> Self
pub fn references(target: impl Into<String>) -> Self
Creates a new GraphQueryTask for finding references.
Sourcepub fn impact_analysis(target: impl Into<String>) -> Self
pub fn impact_analysis(target: impl Into<String>) -> Self
Creates a new GraphQueryTask for impact analysis.