pub struct ChainFallback { /* private fields */ }Expand description
Chain fallback handler that tries multiple handlers in sequence.
Tries each handler in order until one returns a non-Fail result. If all handlers fail, returns the last Fail result.
Example
use forge_agent::workflow::tools::{ChainFallback, RetryFallback, SkipFallback};
let fallback = ChainFallback::new()
.add(RetryFallback::new(3, 100))
.add(SkipFallback::skip());Implementations
Sourceimpl ChainFallback
impl ChainFallback
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new ChainFallback.
Example
use forge_agent::workflow::tools::ChainFallback;
let fallback = ChainFallback::new();Sourcepub fn add(self, handler: impl FallbackHandler + 'static) -> Self
pub fn add(self, handler: impl FallbackHandler + 'static) -> Self
Adds a handler to the chain.
Arguments
handler- Handler to add to the chain
Returns
Self for builder pattern chaining
Example
use forge_agent::workflow::tools::{ChainFallback, RetryFallback, SkipFallback};
let fallback = ChainFallback::new()
.add(RetryFallback::new(3, 100))
.add(SkipFallback::skip());Trait Implementations
Sourceimpl Clone for ChainFallback
impl Clone for ChainFallback
Sourcefn clone(&self) -> ChainFallback
fn clone(&self) -> ChainFallback
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChainFallback
impl Debug for ChainFallback
Sourceimpl Default for ChainFallback
impl Default for ChainFallback
Sourceimpl FallbackHandler for ChainFallback
impl FallbackHandler for ChainFallback
Sourcefn handle<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
error: &'life1 ToolError,
invocation: &'life2 ToolInvocation,
) -> Pin<Box<dyn Future<Output = FallbackResult> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn handle<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
error: &'life1 ToolError,
invocation: &'life2 ToolInvocation,
) -> Pin<Box<dyn Future<Output = FallbackResult> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Handles a tool execution error. Read more