pub struct ToolInvocationResult {
pub result: ToolResult,
pub guard: Option<ProcessGuard>,
}Expand description
Wrapper for tool invocation results with optional process guard.
ToolInvocationResult contains both the result of the tool execution and an optional RAII guard for long-running processes.
Fields
result: ToolResultResult of the tool invocation
guard: Option<ProcessGuard>Optional process guard (None for simple commands that complete immediately)
Implementations
Sourceimpl ToolInvocationResult
impl ToolInvocationResult
Sourcepub fn new(result: ToolResult, guard: Option<ProcessGuard>) -> Self
pub fn new(result: ToolResult, guard: Option<ProcessGuard>) -> Self
Creates a new ToolInvocationResult.
Arguments
result- Tool execution resultguard- Optional process guard
Sourcepub fn completed(result: ToolResult) -> Self
pub fn completed(result: ToolResult) -> Self
Creates a result without a process guard (for completed commands).
Arguments
result- Tool execution result